<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>PluginItem</name>
    <message>
        <location filename="../pluginitem.cpp" line="89"/>
        <source>Remove from dock</source>
        <translation>Удалить из дока</translation>
    </message>
</context>
<context>
    <name>QuickPluginItem</name>
    <message>
        <location filename="../quickpluginitem.cpp" line="160"/>
        <source>Remove from dock</source>
        <translation>Удалить из дока</translation>
    </message>
    <message>
        <location filename="../quickpluginitem.cpp" line="160"/>
        <source>Pin to dock</source>
        <translation>Прикрепить к доку</translation>
    </message>
</context>
</TS>